@@ -3,7 +3,6 @@ from __future__ import annotations
 import argparse
 import ast
 import sys
-from typing import Any
 from typing import Sequence
 from typing import Tuple
 
@@ -23,19 +22,31 @@ def name_lineno_coloffset(tokens: Token) -> tuple[str, int, int]:
 
 
 def record_name_lineno_coloffset(
-    node: Any,
+    node: ast.Name,
     end_lineno: int | None = None,
     end_col_offset: int | None = None,
 ) -> Token:
+    if end_lineno is None:
+        assert node.end_lineno is not None
+        _end_lineno = node.end_lineno
+    else:
+        _end_lineno = end_lineno
+    if end_col_offset is None:
+        assert node.end_col_offset is not None
+        _end_col_offset = node.end_col_offset
+    else:
+        _end_col_offset = end_col_offset
     return (
-        node.id, node.lineno, node.col_offset,
-        end_lineno or node.end_lineno,
-        end_col_offset or node.end_col_offset,
+        node.id,
+        node.lineno,
+        node.col_offset,
+        _end_lineno,
+        _end_col_offset,
     )
 
 
 def find_names(
-    node: Any,
+    node: ast.AST,
     end_lineno: int | None = None,
     end_col_offset: int | None = None,
 ) -> set[Token]:
@@ -50,7 +61,10 @@ def find_names(
     return names
 
 
-def visit_function_def(node: Any, path: str) -> list[tuple[Token, Token]]:
+def visit_function_def(
+    node: ast.FunctionDef,
+    path: str,
+) -> list[tuple[Token, Token]]:
     names = set()
     assignments = set()
     ifs = set()
